Coverage report

File | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | ---
src/pydantic_typer/__init__.py | 1 | 0 | 0 | 0 | 0 | 100%
src/pydantic_typer/main.py | 64 | 0 | 0 | 24 | 1 | 99%
src/pydantic_typer/utils.py | 18 | 1 | 1 | 8 | 1 | 92%
tests/__init__.py | 0 | 0 | 0 | 0 | 0 | 100%
tests/test_001_basic.py | 18 | 0 | 0 | 0 | 0 | 100%
tests/test_002_nested_models.py | 17 | 0 | 0 | 0 | 0 | 100%
tests/test_003_annotated_argument copy.py | 22 | 0 | 0 | 0 | 0 | 100%
tests/test_004_argument_override.py | 18 | 0 | 0 | 0 | 0 | 100%
Total | 158 | 1 | 1 | 32 | 2 | 98%

No items found using the specified filter.